Module: I18nOnSteroids

Defined in:
lib/i18n_on_steroids/version.rb,
lib/i18n_on_steroids.rb,
lib/i18n_on_steroids/console_helpers.rb,
lib/i18n_on_steroids/translation_helper.rb

Overview

Reminder to self with how Semantic Versioning works:

MAJOR version when you make incompatible API changes MINOR version when you add functionality in a backward compatible manner PATCH version when you make backward compatible bug fixes

Additional labels for pre-release and build metadata are available as extensions to the MAJOR.MINOR.PATCH format.

Defined Under Namespace

Modules: ConsoleHelpers, TranslationHelper Classes: Configuration, Error, Railtie

Constant Summary collapse

VERSION =
"1.0.0"

Class Method Summary collapse

Class Method Details

.configurationObject



22
23
24
# File 'lib/i18n_on_steroids/translation_helper.rb', line 22

def self.configuration
  @configuration ||= Configuration.new
end

.configure {|configuration| ... } ⇒ Object

Yields:



26
27
28
# File 'lib/i18n_on_steroids/translation_helper.rb', line 26

def self.configure
  yield(configuration)
end

.demoObject

Convenience methods at module level



209
210
211
# File 'lib/i18n_on_steroids/console_helpers.rb', line 209

def self.demo
  ConsoleHelpers.demo
end

.list_pipesObject



217
218
219
# File 'lib/i18n_on_steroids/console_helpers.rb', line 217

def self.list_pipes
  ConsoleHelpers.list_pipes
end

.pipe_info(name) ⇒ Object



221
222
223
# File 'lib/i18n_on_steroids/console_helpers.rb', line 221

def self.pipe_info(name)
  ConsoleHelpers.pipe_info(name)
end

.test_pipe(*args) ⇒ Object



213
214
215
# File 'lib/i18n_on_steroids/console_helpers.rb', line 213

def self.test_pipe(*args)
  ConsoleHelpers.test_pipe(*args)
end